Upgrading — OppiaMobile 0.1.20 documentation

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.1.20 documentation »

# Upgrading

Before you upgrade, if you have made any changes to your `local_settings.py` file (for example to add your Google Analytics tracking code or turning off self registration) then you should backup your local settings as these may get overwritten during the upgrade process.

To upgrade django-oppia, we recommend that you first uninstall the old version (`pip uninstall django-oppia`) and then install the new version (`pip install django-oppia`).

If you try to upgrade (`pip install --upgrade django-oppia`) , it may also reinstall TastyPie and you’ll need to reapply the timezone fix.

Once you have reinstalled OppiaMobile, run `python manage.py migrate oppia` and `python manage.py migrate oppia.quiz` to apply any database updates.

You should also then put back any changes to your local_settings.py file.

Run `python manage.py collectstatic` this will copy all the required javascript, images, css and other static files are copied to your STATIC_ROOT

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.1.20 documentation »